==> v10.0.1.tar.gz: bookmarks/l10n/ja.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "ブックマーク",
    "You bookmarked \"%s\"" : "「%s」をブックマークしました",
    "%1$s bookmarked \"%2$s\"" : "%1$sさんは「%2$s」をブックマークしました",
    "Someone bookmarked \"%s\"" : "どなたか「%s」をブックマークしました",
    "You deleted \"%s\"" : "「%s」を削除しました",
    "%1$s deleted \"%2$s\"" : "%1$sさんは「%2$s」を削除しました",
    "Someone deleted \"%s\"" : "どなたか「%s」を削除しました",
    "You created folder \"%s\"" : "フォルダー「%s」を作成しました",
    "%1$s created folder \"%2$s\"" : "%1$sさんはフォルダー「%2$s」を作成しました",
    "Someone created folder \"%s\"" : "どなたかフォルダー「%s」を作成しました",
    "You moved folder \"%s\"" : "「%s」を移動しました",
    "%1$s moved folder \"%2$s\"" : "%1$sさんはフォルダー「%2$s」を移動しました",
    "Someone moved folder \"%s\"" : "どなたかフォルダー「%s」を移動しました",
    "You deleted folder \"%s\"" : "フォルダー「%s」を削除しました",
    "%1$s deleted folder \"%2$s\"" : "%1$sさんはフォルダー「%2$s」を削除しました",
    "Someone deleted folder \"%s\"" : "どなたかフォルダー「%s」を削除しました",
    "You shared folder \"%1$s\" with %2$s" : "あなたはフォルダー「%1$s」を%2$sさんと共有しました",
    "You shared folder \"%s\" with someone" : "あなたはフォルダー「%s」をどなたかと共有しました",
    "%1$s shared folder \"%2$s\" with you" : "%1$sさんはフォルダー「%2$s」をあなたと共有しました",
    "Someone shared folder \"%s\" with you" : "どなたかフォルダー「%s」をあなたと共有しました",
    "You unshared folder \"%1$s\" with %2$s" : "あなたはフォルダー「%1$s」を%2$sさんとの共有を解除しました",
    "You unshared folder \"%s\" with someone" : "あなたはフォルダー「%s」をどなたかとの共有を解除しました",
    "%1$s unshared folder \"%2$s\" with you" : "%1$sさんはフォルダー「%2$s」をあなたとの共有を解除しました",
    "Someone unshared folder \"%s\" with you" : "どなたかフォルダー「%s」をあなたとの共有を解除しました",
    "No file provided for import" : "インポート用に提供されたファイルがありません",
    "Unsupported file type for import" : "インポートでサポートされていないファイル形式です",
    "Bookmarks shared by %s" : "%sさんから共有されたブックマーク",
    "Recent bookmarks" : "最新のブックマーク",
    "Bookmark" : "ブックマーク",
    "Bookmark deleted" : "ブックマーク削除時",
    "Bookmark created" : "ブックマーク作成時",
    "Bookmark moved" : "ブックマーク移動時",
    "Bookmark updated" : "ブックマーク更新時",
    "Create bookmark" : "ブックマークを作成",
    "Takes a link and adds it to your collection of bookmarks." : "リンクを取得し、ブックマークのコレクションに追加します。",
    "A Bookmark manager for Nextcloud" : "Nextcloud のブックマークマネージャー",
    "Enter new title" : "新しいタイトルを入力",
    "Select bookmark" : "ブックマークを選択",
    "Details" : "詳細",
    "Rename" : "名前の変更",
    "Move" : "移動",
    "Delete" : "削除",
    "Do you really want to delete this bookmark?" : "本当にこのブックマークを削除しますか？",
    "Open all selected" : "選択されたすべてを開く",
    "Move selection" : "選択した項目を移動",
    "Edit tags of selection" : "選択した項目のタグを編集",
    "Delete selection" : "選択した項目を削除",
    "Select all" : "すべて選択",
    "Cancel selection" : "選択を解除",
    "Selected {folders} folders and {bookmarks} bookmarks" : " {folders} フォルダーと {bookmarks} ブックマークが選択済み",
    "Do you really want to delete these items?" : "本当にこちらの項目を削除しますか？",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%nブックマークが選択済み"],
    "_Selected %n folder_::_Selected %n folders_" : ["%nフォルダーが選択済み"],
    "Go back" : "戻る",
    "Share folder" : "フォルダーを共有",
    "Select one or more tags" : "1つ以上のタグを選択",
    "New" : "新規作成",
    "New bookmark" : "新しいブックマーク",
    "New folder" : "新しいフォルダー",
    "Sort by created date" : "作成日時順",
    "Sort by last modified" : "最終変更日時順",
    "Sort by title" : "タイトル順",
    "Sort by click count" : "クリック数順",
    "RSS feed copied" : "RSSフィードをコピーしました",
    "Enter a link" : "リンクを入力",
    "Enter a title" : "タイトルを入力",
    "No bookmarks found" : "ブックマークが見つかりません",
    "Select folder" : "フォルダーを選択",
    "Enter folder title" : "フォルダーのタイトルを入力",
    "Shared by {user}" : "{user} から共有されました",
    "Rename folder" : "フォルダーの名前を変更",
    "Move folder" : "フォルダーを移動",
    "Delete folder" : "フォルダーを削除",
    "Do you really want to delete this folder?" : "本当にこのフォルダーを削除しますか？",
    "Choose folder" : "フォルダーを選択",
    "Submit" : "送信",
    "Cancel" : "キャンセル",
    "Deleting bookmarks" : "ブックマークを削除中",
    "Deleting selection" : "選択済みを削除中",
    "Importing bookmarks" : "ブックマークをインポート中",
    "Moving selection" : "選択済みを移動中",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n個のフォルダーといくつかのブックマークを移動中"],
    "_Moving %n folder_::_Moving %n folders_" : ["%n個のフォルダーを移動中"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n個のブックマークを移動中"],
    "All bookmarks" : "すべてのブックマーク",
    "Recent" : "最新",
    "Files" : "ファイル",
    "Broken links" : "壊れたリンク",
    "New tag" : "新しいタグ",
    "Untagged" : "タグなし",
    "{used} bookmarks of {available} available" : "利用可能ブックマーク数 {available} のうち{used} が使用済み ",
    "No bookmarked files" : "ブックマーク済みファイルがありません",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "写真やPDFといったファイルへのブックマークは、自動的にNextcloudファイルとして保存されるため、リンクがオフラインになっても見つけることができます。",
    "No bookmarks here" : "ブックマークがありません",
    "Start by importing bookmarks from a file or synchronizing your browser bookmarks with this app" : "ブックマークをファイルからインポートが、このアプリであなたのブラウザーブックマークと同期して始めましょう",
    "Import bookmarks" : "ブックマークをインポート",
    "Sync with your browser" : "ブラウザーと同期",
    "Import" : "インポート",
    "Export" : "エクスポート",
    "Archive path" : "アーカイブパス",
    "Enter the path of a folder where bookmarked files should be stored" : "ブックマークしたファイルの保存先のフォルダーパスを入力してください",
    "Client apps" : "クライアントアプリ",
    "Also check out the collection of client apps that integrate with this app: " : "このアプリと連携するクライアントアプリもご確認ください：",
    "Install on home screen" : "ホーム画面でインストール",
    "Bookmarklet" : "ブックマークレット",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "これをお使いのブラウザーのブックマークにドラッグしてクリックすれば、すぐにウェブページをブックマークできます",
    "Add to {instanceName}" : "{instanceName}に追加",
    "Clear data" : "データを消去",
    "Permanently remove all bookmarks from your account." : "すべてのブックマークを永久にあなたのアカウントから削除します。",
    "Delete all bookmarks" : "すべてのブックマークを削除",
    "Do you really want to delete all your bookmarks?" : "本当にすべてのブックマークを削除しますか？",
    "Please select \"Add to home screen\" in your browser menu" : "お使いのブラウザーで「ホーム画面に追加」を選択してください",
    "Title" : "タイトル",
    "Link" : "リンク",
    "Tags" : "タグ",
    "Select tags and create new ones" : "タグを選択もしくは新規作成",
    "Notes" : "ノート",
    "Notes for this bookmark …" : "このブックマークのメモ…",
    "Archived file" : "アーカイブ済みファイル",
    "Open file" : "ファイルを開く",
    "Open file location" : "ファイルの場所を開く",
    "Owner" : "所有者",
    "Sharing" : "共有中",
    "Select a user or group" : "ユーザーまたはグループを選択",
    "Share link" : "URLで共有",
    "Copy link" : "リンクをコピー",
    "Copy RSS feed" : "RSSフィードをコピー",
    "Delete link" : "リンクを削除",
    "Create public link" : "公開リンクを作成",
    "Allow editing" : "編集を許可",
    "Allow resharing" : "再共有を許可",
    "Remove share" : "共有を削除",
    "Link copied" : "リンクをコピーしました",
    "Privacy" : "プライバシー",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "ブックマークは、追加したウェブページにアクセスして、それらに関する情報を自動的に追加しようとします。",
    "Enable accessing and collecting information from the web pages you add" : "追加したウェブページへのアクセスと情報収集を有効にします",
    "Performance" : "パフォーマンス",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "大量なユーザーのいるインスタンスで、ブックマーク数をアカウント毎に制限は役を立つかも知れません。",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "アカウントごとに許可されるブックマークの最大数（制限なしの場合は0、デフォルトは制限なし）",
    "Previews" : "プレビュー",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "ブックマークしたサイトの実際なスクリーンショットを表示するために、「ブックマーク」はサードパーティーのサービスを使用してサムネイルを生成できます。",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "screeenly.comで無料でサインアップすることも、自分のサーバーをセットアップすることもできます。",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API キー",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine APIキー",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the pageres cli on your server and bookmarks will find it." : "あなたのサーバーでpageres cliをインストールすれば、「ブックマーク」はpageres cliを見つかれます。",
    "Failed to load settings" : "設定の読込に失敗しました",
    "Failed to save settings" : "設定の保存に失敗しました",
    "Add a bookmark" : "ブックマークを追加",
    "This URL is already bookmarked! Overwrite?" : "このURLはすでにブックマークされています! 上書きしますか?",
    "Enter bookmark title" : "ブックマークのタイトルを入力",
    "Enter bookmark URL" : "ブックマークのURLを入力",
    "Folder" : "フォルダー",
    "Root Folder" : "ルートフォルダー",
    "Save" : "保存",
    "Failed to count unavailable bookmarks" : "利用不可ブックマークの数えに失敗しました",
    "Failed to count archived bookmarks" : "アーカイブ済みのブックマークの数えに失敗しました",
    "Failed to load bookmark" : "ブックマークの読込に失敗しました",
    "Failed to find existing bookmark" : "ブックマークの検索に失敗しました",
    "Failed to create bookmark" : "ブックマークの作成に失敗しました",
    "Failed to save bookmark" : "ブックマークの保存に失敗しました",
    "Failed to move bookmark" : "ブックマークの移動に失敗しました",
    "Failed to delete bookmark" : "ブックマークの削除に失敗しました",
    "Failed to rename tag" : "タグ名の変更に失敗しました",
    "Failed to load tags" : "タグの読込に失敗しました",
    "Failed to load folders" : "フォルダーの読込に失敗しました",
    "Failed to delete folder" : "フォルダーの削除に失敗しました",
    "Failed to create folder" : "ブックマークの作成に失敗しました",
    "Failed to fetch bookmarks." : "ブックマークの取得に失敗しました",
    "Failed to change setting" : "設定の変更に失敗しました",
    "Failed to load setting {key}" : "設定の読込に失敗しました {key}",
    "Failed to update share {shareId}" : "共有の更新に失敗しました {shareId}",
    "Failed to delete share {shareId}" : "共有の削除に失敗しました {shareId}",
    "Bookmarks feed" : "ブックマークフィード"
},
"nplurals=1; plural=0;");

==> v10.4.0.tar.gz: bookmarks/l10n/ja.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "ブックマーク",
    "You bookmarked \"%s\"" : "「%s」をブックマークしました",
    "%1$s bookmarked \"%2$s\"" : "%1$sさんは「%2$s」をブックマークしました",
    "Someone bookmarked \"%s\"" : "誰かが「%s」をブックマークしました",
    "You deleted \"%s\"" : "「%s」を削除しました",
    "%1$s deleted \"%2$s\"" : "%1$sさんは「%2$s」を削除しました",
    "Someone deleted \"%s\"" : "誰かが「%s」を削除しました",
    "You created folder \"%s\"" : "フォルダー「%s」を作成しました",
    "%1$s created folder \"%2$s\"" : "%1$sさんはフォルダー「%2$s」を作成しました",
    "Someone created folder \"%s\"" : "誰かがフォルダー「%s」を作成しました",
    "You moved folder \"%s\"" : "「%s」を移動しました",
    "%1$s moved folder \"%2$s\"" : "%1$sさんはフォルダー「%2$s」を移動しました",
    "Someone moved folder \"%s\"" : "誰かがフォルダー「%s」を移動しました",
    "You deleted folder \"%s\"" : "フォルダー「%s」を削除しました",
    "%1$s deleted folder \"%2$s\"" : "%1$sさんはフォルダー「%2$s」を削除しました",
    "Someone deleted folder \"%s\"" : "誰かがフォルダー「%s」を削除しました",
    "You shared folder \"%1$s\" with %2$s" : "あなたはフォルダー「%1$s」を%2$sさんと共有しました",
    "You shared folder \"%s\" with someone" : "あなたはフォルダー「%s」を誰かと共有しました",
    "%1$s shared folder \"%2$s\" with you" : "%1$sさんはフォルダー「%2$s」をあなたと共有しました",
    "Someone shared folder \"%s\" with you" : "誰かがフォルダー「%s」をあなたと共有しました",
    "You unshared folder \"%1$s\" with %2$s" : "あなたはフォルダー「%1$s」の%2$sさんとの共有を解除しました",
    "You unshared folder \"%s\" with someone" : "あなたはフォルダー「%s」の誰かとの共有を解除しました",
    "%1$s unshared folder \"%2$s\" with you" : "%1$sさんはフォルダー「%2$s」のあなたとの共有を解除しました",
    "Someone unshared folder \"%s\" with you" : "誰かがフォルダー「%s」のあなたとの共有を解除しました",
    "No file provided for import" : "インポート用に提供されたファイルがありません",
    "Unsupported file type for import" : "インポートでサポートされていないファイル形式です",
    "Bookmarks Backups" : "ブックマークのバックアップ",
    "Bookmarks shared by %s" : "%sさんから共有されたブックマーク",
    "Recent bookmarks" : "最新のブックマーク",
    "Bookmark" : "ブックマーク",
    "Bookmark deleted" : "ブックマーク削除時",
    "Bookmark created" : "ブックマーク作成時",
    "Bookmark moved" : "ブックマーク移動時",
    "Bookmark updated" : "ブックマーク更新時",
    "Create bookmark" : "ブックマークを作成",
    "Takes a link and adds it to your collection of bookmarks." : "リンクを取得し、ブックマークのコレクションに追加します。",
    "A Bookmark manager for Nextcloud" : "Nextcloud のブックマークマネージャー",
    "Enter new title" : "新しいタイトルを入力",
    "Select bookmark" : "ブックマークを選択",
    "Details" : "詳細",
    "Rename" : "名前の変更",
    "Move" : "移動",
    "Add to folders" : "フォルダーに追加",
    "Delete" : "削除",
    "Do you really want to delete this bookmark?" : "本当にこのブックマークを削除しますか？",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "ウェブ上の写真やPDFといったファイルへのブックマークは、自動的にNextcloudファイルとして保存されるため、リンクがオフラインになっても見つけることができます。",
    "Open all selected" : "選択されたすべてを開く",
    "Move selection" : "選択した項目を移動",
    "Edit tags of selection" : "選択した項目のタグを編集",
    "Delete selection" : "選択した項目を削除",
    "Select all" : "すべて選択",
    "Cancel selection" : "選択を解除",
    "Selected {folders} folders and {bookmarks} bookmarks" : " {folders} フォルダーと {bookmarks} ブックマークが選択済み",
    "Do you really want to delete these items?" : "本当にこちらの項目を削除しますか？",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%nブックマークが選択済み"],
    "_Selected %n folder_::_Selected %n folders_" : ["%nフォルダーが選択済み"],
    "Go back" : "戻る",
    "Share folder" : "フォルダーを共有",
    "Select one or more tags" : "1つ以上のタグを選択",
    "New" : "新規作成",
    "New bookmark" : "新しいブックマーク",
    "New folder" : "新しいフォルダー",
    "Change to grid view" : "グリッド表示へ変更する",
    "Change to list view" : "リスト表示へ変更する",
    "Sort by created date" : "作成日時順",
    "Sort by last modified" : "最終変更日時順",
    "Sort by title" : "タイトル順",
    "Sort by click count" : "クリック数順",
    "RSS feed copied" : "RSSフィードをコピーしました",
    "Enter a link" : "リンクを入力",
    "Enter a title" : "タイトルを入力",
    "No bookmarks found" : "ブックマークが見つかりません",
    "_%n bookmark_::_%n bookmarks_" : ["%n個のブックマーク"],
    "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
    "Welcome to Bookmarks" : "Bookmarksへようこそ",
    "Add a bookmark" : "ブックマークを追加",
    "Import bookmarks" : "ブックマークをインポート",
    "Sync with your browser" : "ブラウザーと同期",
    "Select folder" : "フォルダーを選択",
    "Enter folder title" : "フォルダーのタイトルを入力",
    "Shared by {user}" : "{user} から共有されました",
    "Rename folder" : "フォルダーの名前を変更",
    "Move folder" : "フォルダーを移動",
    "Delete folder" : "フォルダーを削除",
    "Do you really want to delete this folder?" : "本当にこのフォルダーを削除しますか？",
    "Choose folder" : "フォルダーを選択",
    "Submit" : "送信",
    "Cancel" : "キャンセル",
    "Deleting bookmarks" : "ブックマークを削除中",
    "Deleting selection" : "選択済みを削除中",
    "Importing bookmarks" : "ブックマークをインポート中",
    "Moving selection" : "選択済みを移動中",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n個のフォルダーといくつかのブックマークを移動中"],
    "_Moving %n folder_::_Moving %n folders_" : ["%n個のフォルダーを移動中"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n個のブックマークを移動中"],
    "All bookmarks" : "すべてのブックマーク",
    "Recent" : "最新",
    "Shared with you" : "共有中",
    "Files" : "ファイル",
    "Broken links" : "壊れたリンク",
    "New tag" : "新しいタグ",
    "Search tags" : "タグを検索",
    "Untagged" : "タグなし",
    "{used} bookmarks of {available} available" : "利用可能ブックマーク数 {available} のうち{used} が使用済み ",
    "No bookmarked files" : "ブックマーク済みファイルがありません",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "写真やPDFといったファイルへのブックマークは、自動的にNextcloudファイルとして保存されるため、リンクがオフラインになっても見つけることができます。",
    "No broken links" : "壊れたリンクなし",
    "No bookmarks here" : "ブックマークがありません",
    "Import" : "インポート",
    "Export" : "エクスポート",
    "Archive path" : "アーカイブパス",
    "Backups" : "バックアップ",
    "Enable bookmarks backups" : "ブックマークのバックアップを有効化",
    "Client apps" : "クライアントアプリ",
    "Also check out the collection of client apps that integrate with this app: " : "このアプリと連携するクライアントアプリもご確認ください：",
    "Install on home screen" : "ホーム画面へインストール",
    "Bookmarklet" : "ブックマークレット",
    "Add to {instanceName}" : "{instanceName}に追加",
    "Please select \"Add to home screen\" in your browser menu" : "お使いのブラウザーで「ホーム画面に追加」を選択してください",
    "Title" : "タイトル",
    "Link" : "リンク",
    "Root folder" : "ルートフォルダー",
    "Tags" : "タグ",
    "Select tags and create new ones" : "タグを選択もしくは新規作成",
    "Notes" : "ノート",
    "Notes for this bookmark …" : "このブックマークのメモ…",
    "Archived file" : "アーカイブ済みファイル",
    "Open file" : "ファイルを開く",
    "Open file location" : "ファイルの場所を開く",
    "Projects" : "プロジェクト",
    "Created {time} ago" : "{time} 前に作成した",
    "Owner" : "所有者",
    "Sharing" : "共有中",
    "Select a user or group" : "ユーザーまたはグループを選択",
    "Share link" : "URLで共有",
    "Copy link" : "リンクをコピー",
    "Copy RSS feed" : "RSSフィードをコピー",
    "Delete link" : "リンクを削除",
    "Create public link" : "公開リンクを作成",
    "Allow editing" : "編集を許可",
    "Allow resharing" : "再共有を許可",
    "Remove share" : "共有を削除",
    "Link copied" : "リンクをコピーしました",
    "Privacy" : "プライバシー",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "ブックマークは、追加したウェブページにアクセスして、それらに関する情報を自動的に追加しようとします。",
    "Enable accessing and collecting information from the web pages you add" : "追加したウェブページへのアクセスと情報収集を有効にします",
    "Performance" : "パフォーマンス",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "大量のユーザーがいるインスタンスでは、アカウントごとのブックマーク数を制限することが役に立つ場合があります。",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "アカウントごとに許可されるブックマークの最大数（制限なしの場合は0、デフォルトは制限なし）",
    "Previews" : "プレビュー",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "ブックマークしたサイトの実際のスクリーンショットを表示するために、ブックマーク アプリはサードパーティーのサービスを使用してサムネイルを生成できます。",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "screeenly.comで無料でサインアップすることも、自分のサーバーをセットアップすることもできます。",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API キー",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine APIキー",
    "Pageres CLI" : "Pageres CLI",
    "Failed to save settings" : "設定の保存に失敗しました",
    "Failed to load settings" : "設定の読込に失敗しました",
    "This URL is already bookmarked! Overwrite?" : "このURLはすでにブックマークされています! 上書きしますか?",
    "Enter bookmark title" : "ブックマークのタイトルを入力",
    "Enter bookmark URL" : "ブックマークのURLを入力",
    "Folder" : "フォルダー",
    "Root Folder" : "ルートフォルダー",
    "Save" : "保存",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "ネットワークアクセスはデフォルトで無効になっています。プレビューとfaviconの取得を許可するには、ブックマーク アプリの管理者設定を参照してください。",
    "Failed to count unavailable bookmarks" : "利用不可ブックマークの数えに失敗しました",
    "Failed to count archived bookmarks" : "アーカイブ済みのブックマークの数えに失敗しました",
    "Failed to load bookmark" : "ブックマークの読込に失敗しました",
    "Failed to find existing bookmark" : "ブックマークの検索に失敗しました",
    "Failed to create bookmark" : "ブックマークの作成に失敗しました",
    "Failed to save bookmark" : "ブックマークの保存に失敗しました",
    "Failed to move bookmark" : "ブックマークの移動に失敗しました",
    "Failed to copy bookmark" : "ブックマークのコーピーに失敗しました",
    "Failed to delete bookmark" : "ブックマークの削除に失敗しました",
    "Failed to rename tag" : "タグ名の変更に失敗しました",
    "Failed to load tags" : "タグの読込に失敗しました",
    "Failed to load folders" : "フォルダーの読込に失敗しました",
    "Failed to delete folder" : "フォルダーの削除に失敗しました",
    "Failed to create folder" : "ブックマークの作成に失敗しました",
    "Failed to fetch bookmarks." : "ブックマークの取得に失敗しました",
    "Failed to change setting" : "設定の変更に失敗しました",
    "Failed to load setting {key}" : "設定の読込に失敗しました {key}",
    "Failed to update share {shareId}" : "共有の更新に失敗しました {shareId}",
    "Failed to delete share {shareId}" : "共有の削除に失敗しました {shareId}",
    "No links found in this message" : "このメッセージの中にリンクを見つかりません",
    "Bookmarks feed" : "ブックマークフィード"
},
"nplurals=1; plural=0;");
